@@ -606,13 +606,13 @@ func TestJWKSymmetricRoundtrip(t *testing.T) {
 	jwk1 := JsonWebKey{Key: []byte{1, 2, 3, 4}}
 	marshaled, err := jwk1.MarshalJSON()
 	if err != nil {
-		t.Errorf("failed to marshal valid JWK object", err)
+		t.Errorf("failed to marshal valid JWK object: %s", err)
 	}
 
 	var jwk2 JsonWebKey
 	err = jwk2.UnmarshalJSON(marshaled)
 	if err != nil {
-		t.Errorf("failed to unmarshal valid JWK object", err)
+		t.Errorf("failed to unmarshal valid JWK object: %s", err)
 	}
 
 	if !bytes.Equal(jwk1.Key.([]byte), jwk2.Key.([]byte)) {
@@ -660,3 +660,17 @@ func TestJWKValid(t *testing.T) {
 		}
 	}
 }
+
+func TestJWKBufferSizeCheck(t *testing.T) {
+	key := `{
+		"kty":"EC",
+		"crv":"P-256",
+		"x":"m9GSmJ5iGmAYlMlaOJGSFN_CjN9cIn8GGYExP-C0FBiIXlWTNvGN38R9WdrHcppfsKF0FXMOMyutpHIRaiMxYSA",
+		"y":"ZaPcRZ3q_7T3h-Gwz2i-T2JjJXfj6YVGgKHcFz5zqmg"}`
+	var jwk JsonWebKey
+	jwk.UnmarshalJSON([]byte(key))
+	jwk.Valid() // true
+	// panic: square/go-jose: invalid call to newFixedSizeBuffer (len(data) > length)
+	// github.com/square/go-jose.newFixedSizeBuffer(0xc420014557, 0x41, 0x41, 0x20, 0x0)
+	jwk.Thumbprint(crypto.SHA256)
+}
